@@ -4,7 +4,7 @@ use warnings;
 use utf8;
 
 use 5.008001;
-our $VERSION = '1.25';
+our $VERSION = '1.26';
 
 use Carp ();
 use File::Basename;
@@ -364,7 +364,7 @@ Perl::Build - perl builder
 
 =head1 Install as plenv plugin (Recommended)
 
-    % git clone git://github.com/tokuhirom/Perl-Build.git ~/.plenv/plugins/perl-build/
+    % git clone git://github.com/tokuhirom/Perl-Build.git $(plenv root)/plugins/perl-build/
 
 =head1 CLI interface without dependencies
 
